==> mysql-connector-odbc-5.3.8-src.tar.gz: mysql-connector-odbc-5.3.8-src/setupgui/windows/tooltip.cpp <==
/ * 
 
     C o p y r i g h t   ( c )   2 0 0 7 ,   2 0 1 3 ,   O r a c l e   a n d / o r   i t s   a f f i l i a t e s .   A l l   r i g h t s   r e s e r v e d . 
 
 
 
     T h e   M y S Q L   C o n n e c t o r / O D B C   i s   l i c e n s e d   u n d e r   t h e   t e r m s   o f   t h e   G P L v 2 
 
     < h t t p : / / w w w . g n u . o r g / l i c e n s e s / o l d - l i c e n s e s / g p l - 2 . 0 . h t m l > ,   l i k e   m o s t 
 
     M y S Q L   C o n n e c t o r s .   T h e r e   a r e   s p e c i a l   e x c e p t i o n s   t o   t h e   t e r m s   a n d 
 
     c o n d i t i o n s   o f   t h e   G P L v 2   a s   i t   i s   a p p l i e d   t o   t h i s   s o f t w a r e ,   s e e   t h e 
 
     F L O S S   L i c e n s e   E x c e p t i o n 
 
     < h t t p : / / w w w . m y s q l . c o m / a b o u t / l e g a l / l i c e n s i n g / f o s s - e x c e p t i o n . h t m l > . 
 
   
 
     T h i s   p r o g r a m   i s   f r e e   s o f t w a r e ;   y o u   c a n   r e d i s t r i b u t e   i t   a n d / o r   m o d i f y 
 
     i t   u n d e r   t h e   t e r m s   o f   t h e   G N U   G e n e r a l   P u b l i c   L i c e n s e   a s   p u b l i s h e d 
 
     b y   t h e   F r e e   S o f t w a r e   F o u n d a t i o n ;   v e r s i o n   2   o f   t h e   L i c e n s e . 
 
 
 
     T h i s   p r o g r a m   i s   d i s t r i b u t e d   i n   t h e   h o p e   t h a t   i t   w i l l   b e   u s e f u l ,   b u t 
 
     W I T H O U T   A N Y   W A R R A N T Y ;   w i t h o u t   e v e n   t h e   i m p l i e d   w a r r a n t y   o f   M E R C H A N T A B I L I T Y 
 
     o r   F I T N E S S   F O R   A   P A R T I C U L A R   P U R P O S E .   S e e   t h e   G N U   G e n e r a l   P u b l i c   L i c e n s e 
 
     f o r   m o r e   d e t a i l s . 
 
 
 
     Y o u   s h o u l d   h a v e   r e c e i v e d   a   c o p y   o f   t h e   G N U   G e n e r a l   P u b l i c   L i c e n s e   a l o n g 
 
     w i t h   t h i s   p r o g r a m ;   i f   n o t ,   w r i t e   t o   t h e   F r e e   S o f t w a r e   F o u n d a t i o n ,   I n c . , 
 
     5 1   F r a n k l i n   S t ,   F i f t h   F l o o r ,   B o s t o n ,   M A   0 2 1 1 0 - 1 3 0 1     U S A 
 
 * / 
 
 
 
 # i n c l u d e   < w i n d o w s . h > 
 
 # i n c l u d e   < c o m m c t r l . h > 
 
 # i n c l u d e   " r e s o u r c e . h " 
 
 
 
 / /   D o C r e a t e D i a l o g T o o l t i p   -   c r e a t e s   a   t o o l t i p   c o n t r o l   f o r   a   d i a l o g   b o x , 
 
 / /           e n u m e r a t e s   t h e   c h i l d   c o n t r o l   w i n d o w s ,   a n d   i n s t a l l s   a   h o o k 
 
 / /           p r o c e d u r e   t o   m o n i t o r   t h e   m e s s a g e   s t r e a m   f o r   m o u s e   m e s s a g e s   p o s t e d 
 
 / /           t o   t h e   c o n t r o l   w i n d o w s . 
 
 / /   R e t u r n s   T R U E   i f   s u c c e s s f u l   o r   F A L S E   o t h e r w i s e . 
 
 / / 
 
 / /   G l o b a l   v a r i a b l e s 
 
 / /   g _ h i n s t   -   h a n d l e   o f   t h e   a p p l i c a t i o n   i n s t a n c e 
 
 / /   g _ h w n d T T   -   h a n d l e   o f   t h e   t o o l t i p   c o n t r o l 
 
 / /   g _ h w n d D l g   -   h a n d l e   o f   t h e   d i a l o g   b o x 
 
 
 
 / /   g _ h h k   -   h a n d l e   o f   t h e   h o o k   p r o c e d u r e 
 
 H H O O K   g _ h h k ; 
 
 H W N D   g _ h w n d T T ; 
 
 
 
 e x t e r n   H I N S T A N C E   g h I n s t a n c e ; 
 
 # d e f i n e   g _ h i n s t   g h I n s t a n c e 
 
 
 
 e x t e r n   H W N D   g _ h w n d D l g ; 
 
 
 
 B O O L   C A L L B A C K   E n u m C h i l d P r o c ( H W N D   h w n d C t r l ,   L P A R A M   l P a r a m )   ; 
 
 L R E S U L T   C A L L B A C K   G e t M s g P r o c ( i n t   n C o d e ,   W P A R A M   w P a r a m ,   L P A R A M   l P a r a m )   ; 
 
 
 
 B O O L   D o C r e a t e D i a l o g T o o l t i p ( v o i d ) 
 
 { 
 
 
 
         / /   E n s u r e   t h a t   t h e   c o m m o n   c o n t r o l   D L L   i s   l o a d e d ,   a n d   c r e a t e 
 
         / /   a   t o o l t i p   c o n t r o l . 
 
         I n i t C o m m o n C o n t r o l s ( ) ; 
 
         g _ h w n d T T   =   C r e a t e W i n d o w E x ( 0 ,   T O O L T I P S _ C L A S S ,   N U L L , 
 
                 T T S _ A L W A Y S T I P ,   C W _ U S E D E F A U L T ,   C W _ U S E D E F A U L T ,   C W _ U S E D E F A U L T , 
 
                 C W _ U S E D E F A U L T ,   g _ h w n d D l g ,   N U L L ,   g _ h i n s t ,   N U L L ) ; 
 
 
 
         i f   ( g _ h w n d T T   = =   N U L L ) 
 
                 r e t u r n   F A L S E ; 
 
 
 
         / /   E n u m e r a t e   t h e   c h i l d   w i n d o w s   t o   r e g i s t e r   t h e m   w i t h   t h e   t o o l t i p 
 
         / /   c o n t r o l . 
 
 
 
         i f   ( ! E n u m C h i l d W i n d o w s ( g _ h w n d D l g ,   ( W N D E N U M P R O C )   E n u m C h i l d P r o c ,   0 ) ) 
 
                 r e t u r n   F A L S E ; 
 
 
 
         / /   I n s t a l l   a   h o o k   p r o c e d u r e   t o   m o n i t o r   t h e   m e s s a g e   s t r e a m   f o r   m o u s e 
 
         / /   m e s s a g e s   i n t e n d e d   f o r   t h e   c o n t r o l s   i n   t h e   d i a l o g   b o x . 
 
         g _ h h k   =   S e t W i n d o w s H o o k E x ( W H _ G E T M E S S A G E ,   G e t M s g P r o c , 
 
                 ( H I N S T A N C E )   N U L L ,   G e t C u r r e n t T h r e a d I d ( ) ) ; 
 
 
 
         i f   ( g _ h h k   = =   ( H H O O K )   N U L L ) 
 
                 r e t u r n   F A L S E ; 
 
 
 
         r e t u r n   T R U E ; 
 
 } 
 
 
 
 / /   E m u m C h i l d P r o c   -   r e g i s t e r s   c o n t r o l   w i n d o w s   w i t h   a   t o o l t i p   c o n t r o l   b y 
 
 / /           u s i n g   t h e   T T M _ A D D T O O L   m e s s a g e   t o   p a s s   t h e   a d d r e s s   o f   a 
 
 
 
 / /           T O O L I N F O   s t r u c t u r e . 
 
 / /   R e t u r n s   T R U E   i f   s u c c e s s f u l   o r   F A L S E   o t h e r w i s e . 
 
 / /   h w n d C t r l   -   h a n d l e   o f   a   c o n t r o l   w i n d o w 
 
 / /   l P a r a m   -   a p p l i c a t i o n - d e f i n e d   v a l u e   ( n o t   u s e d ) 
 
 B O O L   C A L L B A C K   E n u m C h i l d P r o c ( H W N D   h w n d C t r l ,   L P A R A M   l P a r a m ) 
 
 { 
 
         T O O L I N F O   t i ; 
 
         w c h a r _ t   s z C l a s s [ 6 4 ] ; 
 
 
 
         / /   S k i p   s t a t i c   c o n t r o l s . 
 
         G e t C l a s s N a m e ( h w n d C t r l ,   s z C l a s s ,   s i z e o f ( s z C l a s s ) ) ; 
 
         i f   ( ! l s t r c m p ( s z C l a s s ,   L " E d i t " ) )   { 
 
                 t i . c b S i z e   =   s i z e o f ( T O O L I N F O ) ; 
 
                 t i . u F l a g s   =   T T F _ I D I S H W N D ; 
 
 
 
                 t i . h w n d   =   g _ h w n d D l g ; 
 
                 t i . u I d   =   ( U I N T )   h w n d C t r l ; 
 
                 t i . h i n s t   =   g _ h i n s t ; 
 
                 t i . l p s z T e x t   =   L P S T R _ T E X T C A L L B A C K ; 
 
                 i n t   r e s   =   S e n d M e s s a g e ( g _ h w n d T T ,   T T M _ A D D T O O L ,   0 , 
 
                         ( L P A R A M )   ( L P T O O L I N F O )   & t i ) ; 
 
 	 	 i n t   e   =   G e t L a s t E r r o r ( ) ; 
 
 	 	 r e s + + ; 
 
         } 
 
         r e t u r n   T R U E ; 
 
 } 
 
 
 
 / /   G e t M s g P r o c   -   m o n i t o r s   t h e   m e s s a g e   s t r e a m   f o r   m o u s e   m e s s a g e s   i n t e n d e d 
 
 / /           f o r   a   c o n t r o l   w i n d o w   i n   t h e   d i a l o g   b o x . 
 
 / /   R e t u r n s   a   m e s s a g e - d e p e n d e n t   v a l u e . 
 
 / /   n C o d e   -   h o o k   c o d e 
 
 / /   w P a r a m   -   m e s s a g e   f l a g   ( n o t   u s e d ) 
 
 
 
 / /   l P a r a m   -   a d d r e s s   o f   a n   M S G   s t r u c t u r e 
 
 L R E S U L T   C A L L B A C K   G e t M s g P r o c ( i n t   n C o d e ,   W P A R A M   w P a r a m ,   L P A R A M   l P a r a m ) 
 
 { 
 
         M S G   * l p m s g ; 
 
 
 
         l p m s g   =   ( M S G   * )   l P a r a m ; 
 
         i f   ( n C o d e   <   0   | |   ! ( I s C h i l d ( g _ h w n d D l g ,   l p m s g - > h w n d ) ) ) 
 
                 r e t u r n   ( C a l l N e x t H o o k E x ( g _ h h k ,   n C o d e ,   w P a r a m ,   l P a r a m ) ) ; 
 
 
 
         s w i t c h   ( l p m s g - > m e s s a g e )   { 
 
                 c a s e   W M _ M O U S E M O V E : 
 
                 c a s e   W M _ L B U T T O N D O W N : 
 
                 c a s e   W M _ L B U T T O N U P : 
 
                 c a s e   W M _ R B U T T O N D O W N : 
 
                 c a s e   W M _ R B U T T O N U P : 
 
                         i f   ( g _ h w n d T T   ! =   N U L L )   { 
 
 
 
                                 M S G   m s g ; 
 
 
 
                                 m s g . l P a r a m   =   l p m s g - > l P a r a m ; 
 
                                 m s g . w P a r a m   =   l p m s g - > w P a r a m ; 
 
                                 m s g . m e s s a g e   =   l p m s g - > m e s s a g e ; 
 
                                 m s g . h w n d   =   l p m s g - > h w n d ; 
 
                                 S e n d M e s s a g e ( g _ h w n d T T ,   T T M _ R E L A Y E V E N T ,   0 , 
 
                                         ( L P A R A M )   ( L P M S G )   & m s g ) ; 
 
                         } 
 
                         b r e a k ; 
 
                 d e f a u l t : 
 
                         b r e a k ; 
 
         } 
 
         r e t u r n   ( C a l l N e x t H o o k E x ( g _ h h k ,   n C o d e ,   w P a r a m ,   l P a r a m ) ) ; 
 
 } 
 
 
 
 / /   O n W M N o t i f y   -   p r o v i d e s   t h e   t o o l t i p   c o n t r o l   w i t h   t h e   a p p r o p r i a t e   t e x t 
 
 
 
 / /           t o   d i s p l a y   f o r   a   c o n t r o l   w i n d o w .   T h i s   f u n c t i o n   i s   c a l l e d   b y 
 
 / /           t h e   d i a l o g   b o x   p r o c e d u r e   i n   r e s p o n s e   t o   a   W M _ N O T I F Y   m e s s a g e . 
 
 / /   l P a r a m   -   s e c o n d   m e s s a g e   p a r a m e t e r   o f   t h e   W M _ N O T I F Y   m e s s a g e 
 
 V O I D   O n W M N o t i f y ( W P A R A M   w P a r a m ,   L P A R A M   l P a r a m ) 
 
 { 
 
         L P T O O L T I P T E X T   l p t t t ; 
 
         i n t   i d C t r l ; 
 
 
 
         i f   ( ( ( ( L P N M H D R )   l P a r a m ) - > c o d e )   = =   T T N _ N E E D T E X T )   { 
 
                 i d C t r l   =   G e t D l g C t r l I D ( ( H W N D )   ( ( L P N M H D R )   l P a r a m ) - > i d F r o m ) ; 
 
                 l p t t t   =   ( L P T O O L T I P T E X T )   l P a r a m ; 
 
 
 
                 s w i t c h   ( i d C t r l )   { 
 
 # d e f i n e   S E T _ T I P ( e d i t , t i p ) \ 
 
 	 	 	 c a s e   I D C _ E D I T _ # # e d i t :   \ 
 
                                 l p t t t - > l p s z T e x t   =   t i p ;   \ 
 
                                 r e t u r n ; 
 
 
 
 	 	 	 S E T _ T I P ( d r v n a m e ,   L " A n   u n i q u e   n a m e   f o r   t h i s   d a t a   s o u r c e " ) ; 
 
 	 	 	 S E T _ T I P ( d r v d e s c ,   L " A   b r i e f   d e s c r i p t i o n   f o r   t h i s   d a t a   s o u r c e " ) ; 
 
 	 	 	 S E T _ T I P ( s r v n a m e ,   L " T h e   h o s t n a m e   f o r   t h e   M y S Q L   S e r v e r " ) ; 
 
 	 	 	 S E T _ T I P ( p o r t ,   L " T h e   T C P / I P   p o r t   t o   u s e   i f   s e r v e r   i s   n o t   l o c a l h o s t " ) ; 
 
 	 	 	 S E T _ T I P ( u s e r n a m e ,   L " T h e   u s e r n a m e   u s e d   t o   c o n n e c t   t o   M y S Q L " ) ; 
 
 	 	 	 S E T _ T I P ( p a s s w o r d ,   L " T h e   p a s s w o r d   f o r   t h e   s e r v e r   u s e r   c o m b i n a t i o n " ) ; 
 
 	 	 	 S E T _ T I P ( d b n a m e ,   L " T h e   d a t a b a s e   t o   b e   c u r r e n t   u p o n   c o n n e c t " ) ; 
 
                 } 
 
         } 
 
 r e t u r n ; 
 
 } 
 
 
 
 v o i d   O n D i a l o g C l o s e ( ) 
 
 { 
 
         i f   ( g _ h h k   ! =   ( H H O O K )   N U L L ) 
 
         { 
 
                 U n h o o k W i n d o w s H o o k E x (   g _ h h k   ) ; 
 
         } 
 
 } 
 
 

==> mysql-connector-odbc-5.3.10-src.tar.gz: mysql-connector-odbc-5.3.10-src/setupgui/windows/tooltip.cpp <==
/ *   C o p y r i g h t   ( c )   2 0 0 0 ,   2 0 1 6 ,   O r a c l e   a n d / o r   i t s   a f f i l i a t e s .   A l l   r i g h t s   r e s e r v e d . 
 
 
 
       T h i s   p r o g r a m   i s   f r e e   s o f t w a r e ;   y o u   c a n   r e d i s t r i b u t e   i t   a n d / o r   m o d i f y 
 
       i t   u n d e r   t h e   t e r m s   o f   t h e   G N U   G e n e r a l   P u b l i c   L i c e n s e   a s   p u b l i s h e d   b y 
 
       t h e   F r e e   S o f t w a r e   F o u n d a t i o n ;   v e r s i o n   2   o f   t h e   L i c e n s e . 
 
 
 
       T h i s   p r o g r a m   i s   d i s t r i b u t e d   i n   t h e   h o p e   t h a t   i t   w i l l   b e   u s e f u l , 
 
       b u t   W I T H O U T   A N Y   W A R R A N T Y ;   w i t h o u t   e v e n   t h e   i m p l i e d   w a r r a n t y   o f 
 
       M E R C H A N T A B I L I T Y   o r   F I T N E S S   F O R   A   P A R T I C U L A R   P U R P O S E .     S e e   t h e 
 
       G N U   G e n e r a l   P u b l i c   L i c e n s e   f o r   m o r e   d e t a i l s . 
 
 
 
       Y o u   s h o u l d   h a v e   r e c e i v e d   a   c o p y   o f   t h e   G N U   G e n e r a l   P u b l i c   L i c e n s e 
 
       a l o n g   w i t h   t h i s   p r o g r a m ;   i f   n o t ,   w r i t e   t o   t h e   F r e e   S o f t w a r e 
 
       F o u n d a t i o n ,   I n c . ,   5 1   F r a n k l i n   S t ,   F i f t h   F l o o r ,   B o s t o n ,   M A   0 2 1 1 0 - 1 3 0 1     U S A   * / 
 
 
 
 # i n c l u d e   < w i n d o w s . h > 
 
 # i n c l u d e   < c o m m c t r l . h > 
 
 # i n c l u d e   " r e s o u r c e . h " 
 
 
 
 / /   D o C r e a t e D i a l o g T o o l t i p   -   c r e a t e s   a   t o o l t i p   c o n t r o l   f o r   a   d i a l o g   b o x , 
 
 / /           e n u m e r a t e s   t h e   c h i l d   c o n t r o l   w i n d o w s ,   a n d   i n s t a l l s   a   h o o k 
 
 / /           p r o c e d u r e   t o   m o n i t o r   t h e   m e s s a g e   s t r e a m   f o r   m o u s e   m e s s a g e s   p o s t e d 
 
 / /           t o   t h e   c o n t r o l   w i n d o w s . 
 
 / /   R e t u r n s   T R U E   i f   s u c c e s s f u l   o r   F A L S E   o t h e r w i s e . 
 
 / / 
 
 / /   G l o b a l   v a r i a b l e s 
 
 / /   g _ h i n s t   -   h a n d l e   o f   t h e   a p p l i c a t i o n   i n s t a n c e 
 
 / /   g _ h w n d T T   -   h a n d l e   o f   t h e   t o o l t i p   c o n t r o l 
 
 / /   g _ h w n d D l g   -   h a n d l e   o f   t h e   d i a l o g   b o x 
 
 
 
 / /   g _ h h k   -   h a n d l e   o f   t h e   h o o k   p r o c e d u r e 
 
 H H O O K   g _ h h k ; 
 
 H W N D   g _ h w n d T T ; 
 
 
 
 e x t e r n   H I N S T A N C E   g h I n s t a n c e ; 
 
 # d e f i n e   g _ h i n s t   g h I n s t a n c e 
 
 
 
 e x t e r n   H W N D   g _ h w n d D l g ; 
 
 
 
 B O O L   C A L L B A C K   E n u m C h i l d P r o c ( H W N D   h w n d C t r l ,   L P A R A M   l P a r a m )   ; 
 
 L R E S U L T   C A L L B A C K   G e t M s g P r o c ( i n t   n C o d e ,   W P A R A M   w P a r a m ,   L P A R A M   l P a r a m )   ; 
 
 
 
 B O O L   D o C r e a t e D i a l o g T o o l t i p ( v o i d ) 
 
 { 
 
 
 
         / /   E n s u r e   t h a t   t h e   c o m m o n   c o n t r o l   D L L   i s   l o a d e d ,   a n d   c r e a t e 
 
         / /   a   t o o l t i p   c o n t r o l . 
 
         I n i t C o m m o n C o n t r o l s ( ) ; 
 
         g _ h w n d T T   =   C r e a t e W i n d o w E x ( 0 ,   T O O L T I P S _ C L A S S ,   N U L L , 
 
                 T T S _ A L W A Y S T I P ,   C W _ U S E D E F A U L T ,   C W _ U S E D E F A U L T ,   C W _ U S E D E F A U L T , 
 
                 C W _ U S E D E F A U L T ,   g _ h w n d D l g ,   N U L L ,   g _ h i n s t ,   N U L L ) ; 
 
 
 
         i f   ( g _ h w n d T T   = =   N U L L ) 
 
                 r e t u r n   F A L S E ; 
 
 
 
         / /   E n u m e r a t e   t h e   c h i l d   w i n d o w s   t o   r e g i s t e r   t h e m   w i t h   t h e   t o o l t i p 
 
         / /   c o n t r o l . 
 
 
 
         i f   ( ! E n u m C h i l d W i n d o w s ( g _ h w n d D l g ,   ( W N D E N U M P R O C )   E n u m C h i l d P r o c ,   0 ) ) 
 
                 r e t u r n   F A L S E ; 
 
 
 
         / /   I n s t a l l   a   h o o k   p r o c e d u r e   t o   m o n i t o r   t h e   m e s s a g e   s t r e a m   f o r   m o u s e 
 
         / /   m e s s a g e s   i n t e n d e d   f o r   t h e   c o n t r o l s   i n   t h e   d i a l o g   b o x . 
 
         g _ h h k   =   S e t W i n d o w s H o o k E x ( W H _ G E T M E S S A G E ,   G e t M s g P r o c , 
 
                 ( H I N S T A N C E )   N U L L ,   G e t C u r r e n t T h r e a d I d ( ) ) ; 
 
 
 
         i f   ( g _ h h k   = =   ( H H O O K )   N U L L ) 
 
                 r e t u r n   F A L S E ; 
 
 
 
         r e t u r n   T R U E ; 
 
 } 
 
 
 
 / /   E m u m C h i l d P r o c   -   r e g i s t e r s   c o n t r o l   w i n d o w s   w i t h   a   t o o l t i p   c o n t r o l   b y 
 
 / /           u s i n g   t h e   T T M _ A D D T O O L   m e s s a g e   t o   p a s s   t h e   a d d r e s s   o f   a 
 
 
 
 / /           T O O L I N F O   s t r u c t u r e . 
 
 / /   R e t u r n s   T R U E   i f   s u c c e s s f u l   o r   F A L S E   o t h e r w i s e . 
 
 / /   h w n d C t r l   -   h a n d l e   o f   a   c o n t r o l   w i n d o w 
 
 / /   l P a r a m   -   a p p l i c a t i o n - d e f i n e d   v a l u e   ( n o t   u s e d ) 
 
 B O O L   C A L L B A C K   E n u m C h i l d P r o c ( H W N D   h w n d C t r l ,   L P A R A M   l P a r a m ) 
 
 { 
 
         T O O L I N F O   t i ; 
 
         w c h a r _ t   s z C l a s s [ 6 4 ] ; 
 
 
 
         / /   S k i p   s t a t i c   c o n t r o l s . 
 
         G e t C l a s s N a m e ( h w n d C t r l ,   s z C l a s s ,   s i z e o f ( s z C l a s s ) ) ; 
 
         i f   ( ! l s t r c m p ( s z C l a s s ,   L " E d i t " ) )   { 
 
                 t i . c b S i z e   =   s i z e o f ( T O O L I N F O ) ; 
 
                 t i . u F l a g s   =   T T F _ I D I S H W N D ; 
 
 
 
                 t i . h w n d   =   g _ h w n d D l g ; 
 
                 t i . u I d   =   ( U I N T )   h w n d C t r l ; 
 
                 t i . h i n s t   =   g _ h i n s t ; 
 
                 t i . l p s z T e x t   =   L P S T R _ T E X T C A L L B A C K ; 
 
                 i n t   r e s   =   S e n d M e s s a g e ( g _ h w n d T T ,   T T M _ A D D T O O L ,   0 , 
 
                         ( L P A R A M )   ( L P T O O L I N F O )   & t i ) ; 
 
 	 	 i n t   e   =   G e t L a s t E r r o r ( ) ; 
 
 	 	 r e s + + ; 
 
         } 
 
         r e t u r n   T R U E ; 
 
 } 
 
 
 
 / /   G e t M s g P r o c   -   m o n i t o r s   t h e   m e s s a g e   s t r e a m   f o r   m o u s e   m e s s a g e s   i n t e n d e d 
 
 / /           f o r   a   c o n t r o l   w i n d o w   i n   t h e   d i a l o g   b o x . 
 
 / /   R e t u r n s   a   m e s s a g e - d e p e n d e n t   v a l u e . 
 
 / /   n C o d e   -   h o o k   c o d e 
 
 / /   w P a r a m   -   m e s s a g e   f l a g   ( n o t   u s e d ) 
 
 
 
 / /   l P a r a m   -   a d d r e s s   o f   a n   M S G   s t r u c t u r e 
 
 L R E S U L T   C A L L B A C K   G e t M s g P r o c ( i n t   n C o d e ,   W P A R A M   w P a r a m ,   L P A R A M   l P a r a m ) 
 
 { 
 
         M S G   * l p m s g ; 
 
 
 
         l p m s g   =   ( M S G   * )   l P a r a m ; 
 
         i f   ( n C o d e   <   0   | |   ! ( I s C h i l d ( g _ h w n d D l g ,   l p m s g - > h w n d ) ) ) 
 
                 r e t u r n   ( C a l l N e x t H o o k E x ( g _ h h k ,   n C o d e ,   w P a r a m ,   l P a r a m ) ) ; 
 
 
 
         s w i t c h   ( l p m s g - > m e s s a g e )   { 
 
                 c a s e   W M _ M O U S E M O V E : 
 
                 c a s e   W M _ L B U T T O N D O W N : 
 
                 c a s e   W M _ L B U T T O N U P : 
 
                 c a s e   W M _ R B U T T O N D O W N : 
 
                 c a s e   W M _ R B U T T O N U P : 
 
                         i f   ( g _ h w n d T T   ! =   N U L L )   { 
 
 
 
                                 M S G   m s g ; 
 
 
 
                                 m s g . l P a r a m   =   l p m s g - > l P a r a m ; 
 
                                 m s g . w P a r a m   =   l p m s g - > w P a r a m ; 
 
                                 m s g . m e s s a g e   =   l p m s g - > m e s s a g e ; 
 
                                 m s g . h w n d   =   l p m s g - > h w n d ; 
 
                                 S e n d M e s s a g e ( g _ h w n d T T ,   T T M _ R E L A Y E V E N T ,   0 , 
 
                                         ( L P A R A M )   ( L P M S G )   & m s g ) ; 
 
                         } 
 
                         b r e a k ; 
 
                 d e f a u l t : 
 
                         b r e a k ; 
 
         } 
 
         r e t u r n   ( C a l l N e x t H o o k E x ( g _ h h k ,   n C o d e ,   w P a r a m ,   l P a r a m ) ) ; 
 
 } 
 
 
 
 / /   O n W M N o t i f y   -   p r o v i d e s   t h e   t o o l t i p   c o n t r o l   w i t h   t h e   a p p r o p r i a t e   t e x t 
 
 
 
 / /           t o   d i s p l a y   f o r   a   c o n t r o l   w i n d o w .   T h i s   f u n c t i o n   i s   c a l l e d   b y 
 
 / /           t h e   d i a l o g   b o x   p r o c e d u r e   i n   r e s p o n s e   t o   a   W M _ N O T I F Y   m e s s a g e . 
 
 / /   l P a r a m   -   s e c o n d   m e s s a g e   p a r a m e t e r   o f   t h e   W M _ N O T I F Y   m e s s a g e 
 
 V O I D   O n W M N o t i f y ( W P A R A M   w P a r a m ,   L P A R A M   l P a r a m ) 
 
 { 
 
         L P T O O L T I P T E X T   l p t t t ; 
 
         i n t   i d C t r l ; 
 
 
 
         i f   ( ( ( ( L P N M H D R )   l P a r a m ) - > c o d e )   = =   T T N _ N E E D T E X T )   { 
 
                 i d C t r l   =   G e t D l g C t r l I D ( ( H W N D )   ( ( L P N M H D R )   l P a r a m ) - > i d F r o m ) ; 
 
                 l p t t t   =   ( L P T O O L T I P T E X T )   l P a r a m ; 
 
 
 
                 s w i t c h   ( i d C t r l )   { 
 
 # d e f i n e   S E T _ T I P ( e d i t , t i p ) \ 
 
 	 	 	 c a s e   I D C _ E D I T _ # # e d i t :   \ 
 
                                 l p t t t - > l p s z T e x t   =   t i p ;   \ 
 
                                 r e t u r n ; 
 
 
 
 	 	 	 S E T _ T I P ( d r v n a m e ,   L " A n   u n i q u e   n a m e   f o r   t h i s   d a t a   s o u r c e " ) ; 
 
 	 	 	 S E T _ T I P ( d r v d e s c ,   L " A   b r i e f   d e s c r i p t i o n   f o r   t h i s   d a t a   s o u r c e " ) ; 
 
 	 	 	 S E T _ T I P ( s r v n a m e ,   L " T h e   h o s t n a m e   f o r   t h e   M y S Q L   S e r v e r " ) ; 
 
 	 	 	 S E T _ T I P ( p o r t ,   L " T h e   T C P / I P   p o r t   t o   u s e   i f   s e r v e r   i s   n o t   l o c a l h o s t " ) ; 
 
 	 	 	 S E T _ T I P ( u s e r n a m e ,   L " T h e   u s e r n a m e   u s e d   t o   c o n n e c t   t o   M y S Q L " ) ; 
 
 	 	 	 S E T _ T I P ( p a s s w o r d ,   L " T h e   p a s s w o r d   f o r   t h e   s e r v e r   u s e r   c o m b i n a t i o n " ) ; 
 
 	 	 	 S E T _ T I P ( d b n a m e ,   L " T h e   d a t a b a s e   t o   b e   c u r r e n t   u p o n   c o n n e c t " ) ; 
 
                 } 
 
         } 
 
 r e t u r n ; 
 
 } 
 
 
 
 v o i d   O n D i a l o g C l o s e ( ) 
 
 { 
 
         i f   ( g _ h h k   ! =   ( H H O O K )   N U L L ) 
 
         { 
 
                 U n h o o k W i n d o w s H o o k E x (   g _ h h k   ) ; 
 
         } 
 
 } 
 
 
